@@ -1,8 +1,5 @@
-/* Hey EMACS -*- linux-c -*- */
-/* $Id: pause.h 1179 2005-06-06 14:42:32Z roms $ */
-
-/*  libticalcs - Ti Calculator library, a part of the TiLP project
- *  Copyright (C) 1999-2005  Romain Livin
+/*  libticalcs - calculator library, a part of the TiLP project
+ *  Copyright (C) 1999-2002  Romain Lievin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,14 +16,14 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#ifndef __TICALCS_PAUSE__
-#define __TICALCS_PAUSE__
+#ifndef __CALCS_PAUSE_H__
+#define __CALCS_PAUSE_H__
 
 // Little pause in milli-seconds
 
-#define PAUSE_BETWEEN_VARS	250	// 250ms
+#define PAUSE_BETWEEN_VARS	250		// 250ms
 
-#if defined(__LINUX__) || defined(__MACOSX__) || defined(__BSD__)
+#if defined(__UNIX__) || defined(__LINUX__) || defined(__MACOSX__)
 # include <unistd.h>
 # define PAUSE(x)  usleep(1000*(x));
 #elif defined(__WIN32__)
@@ -35,3 +32,6 @@
 #endif
 
 #endif
+
+
+
